@@ -287,7 +287,7 @@ _DEEPINFRA_MODELS = [
         provider="deepinfra",
         name="Kimi K2 Instruct",
         description="Kimi K2 is a large-scale Mixture-of-Experts (MoE) language model developed by Moonshot AI, featuring 1 trillion total parameters with 32 billion active per forward pass",
-        capabilities=["text-generation", "tool_use"],
+        capabilities=["text-generation", "tool_use", "stream"],
         input_token_price_1m=0.55,
         output_token_price_1m=2.22,
     ),
@@ -304,7 +304,7 @@ _GITHUB_COPILOT_MODELS = [
         output_token_price_1m=0.0,
     ),
     Model(
-        id="gemini-2.5-pro-preview-05-06",
+        id="gemini-2.5-pro",
         provider="github_copilot",
         name="Gemini 2.5 Pro",
         description="",
@@ -313,6 +313,16 @@ _GITHUB_COPILOT_MODELS = [
         input_token_price_1m=0.0,
         output_token_price_1m=0.0,
     ),
+    Model(
+        id="gemini-2.0-flash-001",
+        provider="github_copilot",
+        name="Gemini 2.0 Flash",
+        description="",
+        capabilities=["tool_use", "vision", "stream"],
+        default=False,
+        input_token_price_1m=0.0,
+        output_token_price_1m=0.0,
+    ),
     Model(
         id="claude-3.7-sonnet-thought",
         provider="github_copilot",
